@@ -20,8 +20,8 @@ CREATE TABLE users (
     username varchar(191) NOT NULL,
     server_host varchar(191) NOT NULL,
     password text NOT NULL,
-    serverkey varchar(64) NOT NULL DEFAULT '',
-    salt varchar(64) NOT NULL DEFAULT '',
+    serverkey varchar(128) NOT NULL DEFAULT '',
+    salt varchar(128) NOT NULL DEFAULT '',
     iterationcount integer NOT NULL DEFAULT 0,
     created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
     PRIMARY KEY (server_host(191), username)
@@ -76,6 +76,8 @@ CREATE TABLE sr_group (
     PRIMARY KEY (server_host(191), name)
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
+CREATE UNIQUE INDEX i_sr_group_sh_name ON sr_group(server_host(191), name);
+
 CREATE TABLE sr_user (
     jid varchar(191) NOT NULL,
     server_host varchar(191) NOT NULL,
@@ -84,6 +86,7 @@ CREATE TABLE sr_user (
     PRIMARY KEY (server_host(191), jid, grp)
 ) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
+CREATE UNIQUE INDEX i_sr_user_sh_jid_group ON sr_user(server_host(191), jid, grp);
 CREATE INDEX i_sr_user_sh_jid ON sr_user(server_host(191), jid);
 CREATE INDEX i_sr_user_sh_grp ON sr_user(server_host(191), grp);
 
@@ -430,7 +433,7 @@ CREATE TABLE push_session (
     node text NOT NULL,
     xml text NOT NULL,
     PRIMARY KEY (server_host(191), username(191), timestamp)
-);
+) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
 
 CREATE UNIQUE INDEX i_push_session_susn ON push_session (server_host(191), username(191), service(191), node(191));
 
@@ -502,4 +505,4 @@ CREATE TABLE mqtt_pub (
     user_properties blob NOT NULL,
     expiry int unsigned NOT NULL,
     UNIQUE KEY i_mqtt_topic_server (topic(191), server_host)
-);
+) ENGINE=InnoDB CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;
