@@ -156,6 +156,12 @@
 -- CREATE INDEX i_sm_sh_username ON sm USING btree (server_host, username);
 -- ALTER TABLE sm ALTER COLUMN server_host DROP DEFAULT;
 
+-- ALTER TABLE push_session ADD COLUMN server_host text NOT NULL DEFAULT '<HOST>';
+-- DROP INDEX i_push_usn;
+-- DROP INDEX i_push_ut;
+-- ALTER TABLE push_session ADD PRIMARY KEY (server_host, username, timestamp);
+-- CREATE UNIQUE INDEX i_push_session_susn ON push_session USING btree (server_host, username, service, node);
+
 
 CREATE TABLE users (
     username text NOT NULL,
@@ -218,6 +224,8 @@ CREATE TABLE sr_group (
     PRIMARY KEY (server_host, name)
 );
 
+CREATE UNIQUE INDEX i_sr_group_sh_name ON sr_group USING btree (server_host, name);
+
 CREATE TABLE sr_user (
     jid text NOT NULL,
     server_host text NOT NULL,
@@ -226,6 +234,7 @@ CREATE TABLE sr_user (
     PRIMARY KEY (server_host, jid, grp)
 );
 
+CREATE UNIQUE INDEX i_sr_user_sh_jid_grp ON sr_user USING btree (server_host, jid, grp);
 CREATE INDEX i_sr_user_sh_jid ON sr_user USING btree (server_host, jid);
 CREATE INDEX i_sr_user_sh_grp ON sr_user USING btree (server_host, grp);
 
@@ -302,7 +311,7 @@ CREATE TABLE vcard_search (
     lorgname text NOT NULL,
     orgunit text NOT NULL,
     lorgunit text NOT NULL,
-    PRIMARY KEY (server_host, username)
+    PRIMARY KEY (server_host, lusername)
 );
 
 CREATE INDEX i_vcard_search_sh_lfn       ON vcard_search(server_host, lfn);
