@@ -880,7 +880,7 @@ get_priority_from_presence(#presence{priority = Prio}) ->
 -spec route_multiple(state(), [jid()], stanza()) -> ok.
 route_multiple(#{lserver := LServer}, JIDs, Pkt) ->
     From = xmpp:get_from(Pkt),
-    ejabberd_router_multicast:route_multicast(From, LServer, JIDs, Pkt).
+    ejabberd_router_multicast:route_multicast(From, LServer, JIDs, Pkt, false).
 
 get_subscription(#jid{luser = LUser, lserver = LServer}, JID) ->
     {Subscription, _, _} = ejabberd_hooks:run_fold(
