@@ -41,6 +41,7 @@
 	 get_tags_commands/0,
 	 get_tags_commands/1,
 	 register_commands/1,
+	 register_commands/2,
 	 unregister_commands/1,
 	 get_commands_spec/0,
 	 get_commands_definition/0,
@@ -90,6 +91,17 @@ get_commands_spec() ->
                                         "that will have example invocation include in markdown document"],
                            result_desc = "0 if command failed, 1 when succeeded",
                            args_example = ["/home/me/docs/api.html", "mod_admin", "java,json"],
+                           result_example = ok},
+        #ejabberd_commands{name = gen_markdown_doc_for_tags, tags = [documentation],
+                           desc = "Generates markdown documentation for ejabberd_commands",
+                           note = "added in 21.12",
+                           module = ejabberd_commands_doc, function = generate_tags_md,
+                           args = [{file, binary}],
+                           result = {res, rescode},
+                           args_desc = ["Path to file where generated "
+                                        "documentation should be stored"],
+                           result_desc = "0 if command failed, 1 when succeeded",
+                           args_example = ["/home/me/docs/tags.md"],
                            result_example = ok}].
 
 start_link() ->
@@ -129,10 +141,13 @@ code_change(_OldVsn, State, _Extra) ->
 -spec register_commands([ejabberd_commands()]) -> ok.
 
 register_commands(Commands) ->
+    register_commands(unknown, Commands).
+
+register_commands(Definer, Commands) ->
     lists:foreach(
       fun(Command) ->
               %% XXX check if command exists
-              mnesia:dirty_write(Command)
+              mnesia:dirty_write(Command#ejabberd_commands{definer = Definer})
               %% ?DEBUG("This command is already defined:~n~p", [Command])
       end,
       Commands),
