@@ -51,7 +51,7 @@
 	 active = false               :: boolean(),
 	 c2s_pid                      :: pid(),
          ws                           :: {#ws{}, pid()},
-         rfc_compilant = undefined    :: boolean() | undefined}).
+         rfc_compliant = undefined    :: boolean() | undefined}).
 
 %-define(DBGFSM, true).
 
@@ -166,7 +166,7 @@ handle_event({new_shaper, Shaper}, StateName, #state{ws = {_, WsPid}} = StateDat
     {next_state, StateName, StateData}.
 
 handle_sync_event({send_xml, Packet}, _From, StateName,
-		  #state{ws = {_, WsPid}, rfc_compilant = R} = StateData) ->
+		  #state{ws = {_, WsPid}, rfc_compliant = R} = StateData) ->
     Packet2 = case {case R of undefined -> true; V -> V end, Packet} of
                   {true, {xmlstreamstart, _, Attrs}} ->
                       Attrs2 = [{<<"xmlns">>, <<"urn:ietf:params:xml:ns:xmpp-framing">>} |
@@ -215,7 +215,7 @@ handle_sync_event({send_xml, Packet}, _From, StateName,
                   StateName
           end,
     {reply, ok, SN2, StateData};
-handle_sync_event(close, _From, StateName, #state{ws = {_, WsPid}, rfc_compilant = true} = StateData)
+handle_sync_event(close, _From, StateName, #state{ws = {_, WsPid}, rfc_compliant = true} = StateData)
   when StateName /= stream_end_sent ->
     Close = #xmlel{name = <<"close">>,
                    attrs = [{<<"xmlns">>, <<"urn:ietf:params:xml:ns:xmpp-framing">>}]},
@@ -313,7 +313,7 @@ get_human_html_xmlel() ->
                                            "client that supports it.">>}]}]}]}.
 
 
-parse(#state{rfc_compilant = C} = State, Data) ->
+parse(#state{rfc_compliant = C} = State, Data) ->
     case C of
         undefined ->
             P = fxml_stream:new(self()),
@@ -321,13 +321,13 @@ parse(#state{rfc_compilant = C} = State, Data) ->
             fxml_stream:close(P2),
             case parsed_items([]) of
                 error ->
-                    {State#state{rfc_compilant = true}, <<"parse error">>};
+                    {State#state{rfc_compliant = true}, <<"parse error">>};
                 [] ->
-                    {State#state{rfc_compilant = true}, <<"parse error">>};
+                    {State#state{rfc_compliant = true}, <<"parse error">>};
                 [{xmlstreamstart, <<"open">>, _} | _] ->
-                    parse(State#state{rfc_compilant = true}, Data);
+                    parse(State#state{rfc_compliant = true}, Data);
                 _ ->
-                    parse(State#state{rfc_compilant = false}, Data)
+                    parse(State#state{rfc_compliant = false}, Data)
             end;
         true ->
             El = fxml_stream:parse_element(Data),
