@@ -73,11 +73,16 @@ export(Server, Output) ->
       end, Modules),
     close_output(Output, IO).
 
-export(Server, Output, Module1) ->
-    Module = case Module1 of
-		 mod_pubsub -> pubsub_db;
-		 _ -> Module1
-	     end,
+export(Server, Output, mod_mam = M1) ->
+    MucServices = gen_mod:get_module_opt_hosts(Server, mod_muc),
+    [export2(MucService, Output, M1, M1) || MucService <- MucServices],
+    export2(Server, Output, M1, M1);
+export(Server, Output, mod_pubsub = M1) ->
+    export2(Server, Output, M1, pubsub_db);
+export(Server, Output, M1) ->
+    export2(Server, Output, M1, M1).
+
+export2(Server, Output, Module1, Module) ->
     SQLMod = gen_mod:db_mod(sql, Module),
     LServer = jid:nameprep(iolist_to_binary(Server)),
     IO = prepare_output(Output),
@@ -104,12 +109,17 @@ delete(Server) ->
               delete(Server, Module)
       end, Modules).
 
-delete(Server, Module) ->
+delete(Server, Module1) ->
     LServer = jid:nameprep(iolist_to_binary(Server)),
+    Module = case Module1 of
+		 mod_pubsub -> pubsub_db;
+		 _ -> Module1
+	     end,
+    SQLMod = gen_mod:db_mod(sql, Module),
     lists:foreach(
       fun({Table, ConvertFun}) ->
               delete(LServer, Table, ConvertFun)
-      end, Module:export(Server)).
+      end, SQLMod:export(Server)).
 
 import(Server, Dir, ToType) ->
     lists:foreach(
@@ -154,6 +164,7 @@ import_info(Mod) ->
 %%% Internal functions
 %%%----------------------------------------------------------------------
 export(LServer, Table, IO, ConvertFun) ->
+    DbType = ejabberd_option:sql_type(LServer),
     F = fun () ->
                 mnesia:read_lock_table(Table),
                 {_N, SQLs} =
@@ -163,7 +174,7 @@ export(LServer, Table, IO, ConvertFun) ->
                                   [] ->
                                       Acc;
                                   SQL1 ->
-                                      SQL = format_queries(SQL1),
+                                      SQL = format_queries(DbType, SQL1),
                                       if N < (?MAX_RECORDS_PER_TRANSACTION) - 1 ->
                                               {N + 1, [SQL | SQLs]};
                                          true ->
@@ -191,7 +202,7 @@ output(_LServer, Table, Fd, SQLs) ->
 delete(LServer, Table, ConvertFun) ->
     F = fun () ->
                 mnesia:write_lock_table(Table),
-                {_N, SQLs} =
+                {_N, _SQLs} =
                     mnesia:foldl(
                       fun(R, Acc) ->
                               case ConvertFun(LServer, R) of
@@ -202,8 +213,7 @@ delete(LServer, Table, ConvertFun) ->
                                       Acc
                               end
                       end,
-                      {0, []}, Table),
-                delete(LServer, Table, SQLs)
+                      {0, []}, Table)
         end,
     mnesia:transaction(F).
 
@@ -368,10 +378,10 @@ format_error({error, eof}) ->
 format_error({error, Posix}) ->
     file:format_error(Posix).
 
-format_queries(SQLs) ->
+format_queries(DbType, SQLs) ->
     lists:map(
       fun(#sql_query{} = SQL) ->
-              ejabberd_sql:sql_query_to_iolist(SQL);
+              ejabberd_sql:sql_query_to_iolist(DbType, SQL);
          (SQL) ->
               SQL
       end, SQLs).
