@@ -122,12 +122,21 @@
     {result, {default, broadcast}} |
     {error, stanza_error()}.
 
+-callback remove_extra_items(NodeIdx :: nodeIdx(),
+	Max_Items :: unlimited | non_neg_integer()) ->
+    {result, {[itemId()], [itemId()]}
+	}.
+
 -callback remove_extra_items(NodeIdx :: nodeIdx(),
 	Max_Items :: unlimited | non_neg_integer(),
 	ItemIds :: [itemId()]) ->
     {result, {[itemId()], [itemId()]}
 	}.
 
+-callback remove_expired_items(NodeIdx :: nodeIdx(),
+	Seconds :: infinity | non_neg_integer()) ->
+    {result, [itemId()]}.
+
 -callback get_node_affiliations(NodeIdx :: nodeIdx()) ->
     {result, [{ljid(), affiliation()}]}.
 
