@@ -92,7 +92,7 @@
 %%%
 
 start(_Host, _Opts) ->
-    ejabberd_commands:register_commands(get_commands_spec()).
+    ejabberd_commands:register_commands(?MODULE, get_commands_spec()).
 
 stop(Host) ->
     case gen_mod:is_loaded_elsewhere(Host, ?MODULE) of
@@ -275,7 +275,7 @@ get_commands_spec() ->
 			result = {res, rescode},
 			result_example = ok,
 			result_desc = "Status code: 0 on success, 1 otherwise"},
-     #ejabberd_commands{name = status_num_host, tags = [session, stats],
+     #ejabberd_commands{name = status_num_host, tags = [session, statistics],
 			desc = "Number of logged users with this status in host",
 			policy = admin,
 			module = ?MODULE, function = status_num,
@@ -285,7 +285,7 @@ get_commands_spec() ->
 			result = {users, integer},
 			result_example = 23,
 			result_desc = "Number of connected sessions with given status type"},
-     #ejabberd_commands{name = status_num, tags = [session, stats],
+     #ejabberd_commands{name = status_num, tags = [session, statistics],
 			desc = "Number of logged users with this status",
 			policy = admin,
 			module = ?MODULE, function = status_num,
@@ -662,9 +662,11 @@ get_commands_spec() ->
 			"For example:\n"
 			"  ejabberdctl srg_create group3 myserver.com "
 			"name desc \\\"group1\\\\ngroup2\\\"",
+			note = "changed in 21.07",
 			module = ?MODULE, function = srg_create,
 			args = [{group, binary}, {host, binary},
-				{name, binary}, {description, binary}, {display, binary}],
+				{label, binary}, {description, binary}, {display, binary}],
+			args_rename = [{name, label}],
 			args_example = [<<"group3">>, <<"myserver.com">>, <<"Group3">>,
 				<<"Third group">>, <<"group1\\\\ngroup2">>],
 			args_desc = ["Group identifier", "Group server name", "Group name",
@@ -744,7 +746,9 @@ get_commands_spec() ->
 				"Receiver JID", "Subject, or empty string", "Body"],
 			result = {res, rescode}},
      #ejabberd_commands{name = send_stanza_c2s, tags = [stanza],
-			desc = "Send a stanza as if sent from a c2s session",
+			desc = "Send a stanza from an existing C2S session",
+			longdesc = "USER@HOST/RESOURCE must be an existing C2S session."
+			" As an alternative, use send_stanza instead.",
 			module = ?MODULE, function = send_stanza_c2s,
 			args = [{user, binary}, {host, binary}, {resource, binary}, {stanza, binary}],
 			args_example = [<<"admin">>, <<"myserver.com">>, <<"bot">>,
@@ -768,7 +772,7 @@ get_commands_spec() ->
 			args_desc = ["Username", "Server name", "Query XML element"],
 			result = {res, rescode}},
 
-     #ejabberd_commands{name = stats, tags = [stats],
+     #ejabberd_commands{name = stats, tags = [statistics],
 			desc = "Get statistical value: registeredusers onlineusers onlineusersnode uptimeseconds processes",
 			policy = admin,
 			module = ?MODULE, function = stats,
@@ -778,7 +782,7 @@ get_commands_spec() ->
 			result_example = 6,
 			result_desc = "Integer statistic value",
 			result = {stat, integer}},
-     #ejabberd_commands{name = stats_host, tags = [stats],
+     #ejabberd_commands{name = stats_host, tags = [statistics],
 			desc = "Get statistical value for this host: registeredusers onlineusers",
 			policy = admin,
 			module = ?MODULE, function = stats,
@@ -1243,23 +1247,42 @@ update_vcard_els(Data, ContentList, Els1) ->
 %%%
 
 add_rosteritem(LocalUser, LocalServer, User, Server, Nick, Group, Subs) ->
-    Jid = jid:make(LocalUser, LocalServer),
-    RosterItem = build_roster_item(User, Server, {add, Nick, Subs, Group}),
-    case mod_roster:set_item_and_notify_clients(Jid, RosterItem, true) of
-	ok -> ok;
-	_ -> error
+    case {jid:make(LocalUser, LocalServer), jid:make(User, Server)} of
+	{error, _} ->
+	    throw({error, "Invalid 'localuser'/'localserver'"});
+	{_, error} ->
+	    throw({error, "Invalid 'user'/'server'"});
+	{Jid, _Jid2} ->
+	    RosterItem = build_roster_item(User, Server, {add, Nick, Subs, Group}),
+	    case mod_roster:set_item_and_notify_clients(Jid, RosterItem, true) of
+		ok -> ok;
+		_ -> error
+	    end
     end.
 
 subscribe(LU, LS, User, Server, Nick, Group, Subscription, _Xattrs) ->
-    ItemEl = build_roster_item(User, Server, {add, Nick, Subscription, Group}),
-    mod_roster:set_items(LU, LS, #roster_query{items = [ItemEl]}).
+    case {jid:make(LU, LS), jid:make(User, Server)} of
+	{error, _} ->
+	    throw({error, "Invalid 'localuser'/'localserver'"});
+	{_, error} ->
+	    throw({error, "Invalid 'user'/'server'"});
+	{_Jid, _Jid2} ->
+	    ItemEl = build_roster_item(User, Server, {add, Nick, Subscription, Group}),
+	    mod_roster:set_items(LU, LS, #roster_query{items = [ItemEl]})
+    end.
 
 delete_rosteritem(LocalUser, LocalServer, User, Server) ->
-    Jid = jid:make(LocalUser, LocalServer),
-    RosterItem = build_roster_item(User, Server, remove),
-    case mod_roster:set_item_and_notify_clients(Jid, RosterItem, true) of
-	ok -> ok;
-	_ -> error
+    case {jid:make(LocalUser, LocalServer), jid:make(User, Server)} of
+	{error, _} ->
+	    throw({error, "Invalid 'localuser'/'localserver'"});
+	{_, error} ->
+	    throw({error, "Invalid 'user'/'server'"});
+	{Jid, _Jid2} ->
+	    RosterItem = build_roster_item(User, Server, remove),
+	    case mod_roster:set_item_and_notify_clients(Jid, RosterItem, true) of
+		ok -> ok;
+		_ -> error
+	    end
     end.
 
 %% -----------------------------
@@ -1267,8 +1290,13 @@ delete_rosteritem(LocalUser, LocalServer, User, Server) ->
 %% -----------------------------
 
 get_roster(User, Server) ->
-    Items = ejabberd_hooks:run_fold(roster_get, Server, [], [{User, Server}]),
-    make_roster_xmlrpc(Items).
+    case jid:make(User, Server) of
+	error ->
+	    throw({error, "Invalid 'user'/'server'"});
+	#jid{luser = U, lserver = S} ->
+	    Items = ejabberd_hooks:run_fold(roster_get, S, [], [{U, S}]),
+	    make_roster_xmlrpc(Items)
+    end.
 
 %% Note: if a contact is in several groups, the contact is returned
 %% several times, each one in a different group.
@@ -1430,12 +1458,12 @@ private_set2(Username, Host, Xml) ->
 %%% Shared Roster Groups
 %%%
 
-srg_create(Group, Host, Name, Description, Display) ->
+srg_create(Group, Host, Label, Description, Display) ->
     DisplayList = case Display of
 	<<>> -> [];
 	_ -> ejabberd_regexp:split(Display, <<"\\\\n">>)
     end,
-    Opts = [{name, Name},
+    Opts = [{label, Label},
 	    {displayed_groups, DisplayList},
 	    {description, Description}],
     {atomic, _} = mod_shared_roster:create_group(Host, Group, Opts),
@@ -1494,10 +1522,10 @@ send_message(Type, From, To, Subject, Body) ->
                       #xmlel{name = <<"body">>,
                              children = [{xmlcdata, Body}]}]},
           ?NS_CLIENT, CodecOpts) of
-        #message{from = JID, subject = Subject, body = Body} = Msg ->
-            Msg2 = case {xmpp:get_text(Subject), xmpp:get_text(Body)} of
-                       {_, <<>>} -> Msg;
-                       {<<>>, _} -> Msg#message{subject = []};
+        #message{from = JID, subject = SubjectEl, body = BodyEl} = Msg ->
+            Msg2 = case {xmpp:get_text(SubjectEl), xmpp:get_text(BodyEl)} of
+                       {Subject, <<>>} -> Msg;
+                       {<<>>, Body} -> Msg#message{subject = []};
                        _ -> Msg
                    end,
             State = #{jid => JID},
@@ -1624,14 +1652,6 @@ mod_doc() ->
            ?T("If you want to put a group Name with blankspaces, use the "
 	      "characters \"\' and \'\" to define when the Name starts and "
 	      "ends. See an example below.")],
-      opts =>
-          [{module_resource,
-            #{value => ?T("Resource"),
-              desc =>
-                  ?T("Indicate the resource that the XMPP stanzas must use "
-		     "in the FROM or TO JIDs. This is only useful in the "
-		     "'get_vcard*' and 'set_vcard*' commands. The default "
-		     "value is 'mod_admin_extra'.")}}],
       example =>
 	  [{?T("With this configuration, vCards can only be modified with "
 	       "mod_admin_extra commands:"),
@@ -1642,8 +1662,7 @@ mod_doc() ->
 	     "  vcard_set:",
 	     "    - allow: adminextraresource",
 	     "modules:",
-	     "  mod_admin_extra:",
-	     "    module_resource: \"modadminextraf8x,31ad\"",
+	     "  mod_admin_extra: {}",
 	     "  mod_vcard:",
 	     "    access_set: vcard_set"]},
 	   {?T("Content of roster file for 'pushroster' command:"),
