@@ -464,11 +464,11 @@ mod_doc() ->
                    "  -",
                    "    modules: all",
                    "    name: abuse-addresses",
-                   "    urls: [mailto:abuse@shakespeare.lit]",
+                   "    urls: [\"mailto:abuse@shakespeare.lit\"]",
                    "  -",
                    "    modules: [mod_muc]",
                    "    name: \"Web chatroom logs\"",
-                   "    urls: [http://www.example.org/muc-logs]",
+                   "    urls: [\"http://www.example.org/muc-logs\"]",
                    "  -",
                    "    modules: [mod_disco]",
                    "    name: feedback-addresses",
