@@ -5,7 +5,7 @@
 %%% Created : 11 Sep 2019 by Holger Weiss <holger@zedat.fu-berlin.de>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2019-2020 ProcessOne
+%%% ejabberd, Copyright (C) 2019-2021 ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -41,7 +41,7 @@
 
 -include("logger.hrl").
 -include("translate.hrl").
--include("xmpp.hrl").
+-include_lib("xmpp/include/xmpp.hrl").
 
 %%--------------------------------------------------------------------
 %% gen_mod callbacks.
