@@ -40,8 +40,10 @@
 	 room_destroyed/4,
 	 store_room/4,
 	 store_room/5,
+	 store_changes/4,
 	 restore_room/3,
 	 forget_room/3,
+	 create_room/3,
 	 create_room/5,
 	 shutdown_rooms/1,
 	 process_disco_info/1,
@@ -90,6 +92,7 @@
 -callback init(binary(), gen_mod:opts()) -> any().
 -callback import(binary(), binary(), [binary()]) -> ok.
 -callback store_room(binary(), binary(), binary(), list(), list()|undefined) -> {atomic, any()}.
+-callback store_changes(binary(), binary(), binary(), list()) -> {atomic, any()}.
 -callback restore_room(binary(), binary(), binary()) -> muc_room_opts() | error.
 -callback forget_room(binary(), binary(), binary()) -> {atomic, any()}.
 -callback can_use_nick(binary(), binary(), jid(), binary()) -> boolean().
@@ -99,6 +102,7 @@
 -callback register_online_room(binary(), binary(), binary(), pid()) -> any().
 -callback unregister_online_room(binary(), binary(), binary(), pid()) -> any().
 -callback find_online_room(binary(), binary(), binary()) -> {ok, pid()} | error.
+-callback find_online_room_by_pid(binary(), pid()) -> {ok, binary(), binary()} | error.
 -callback get_online_rooms(binary(), binary(), undefined | rsm_set()) -> [{binary(), binary(), pid()}].
 -callback count_online_rooms(binary(), binary()) -> non_neg_integer().
 -callback rsm_supported() -> boolean().
@@ -109,7 +113,8 @@
 -callback get_subscribed_rooms(binary(), binary(), jid()) ->
           {ok, [{jid(), binary(), [binary()]}]} | {error, db_failure}.
 
--optional_callbacks([get_subscribed_rooms/3]).
+-optional_callbacks([get_subscribed_rooms/3,
+                     store_changes/4]).
 
 %%====================================================================
 %% API
@@ -295,6 +300,14 @@ create_room(Host, Name, From, Nick, Opts) ->
     Proc = procname(ServerHost, {Name, Host}),
     ?GEN_SERVER:call(Proc, {create, Name, Host, From, Nick, Opts}).
 
+%% @doc Create a room.
+%% If Opts = default, the default room options are used.
+%% Else use the passed options as defined in mod_muc_room.
+create_room(Host, Name, Opts) ->
+    ServerHost = ejabberd_router:host_of_route(Host),
+    Proc = procname(ServerHost, {Name, Host}),
+    ?GEN_SERVER:call(Proc, {create, Name, Host, Opts}).
+
 store_room(ServerHost, Host, Name, Opts) ->
     store_room(ServerHost, Host, Name, Opts, undefined).
 
@@ -303,6 +316,11 @@ store_room(ServerHost, Host, Name, Opts, ChangesHints) ->
     Mod = gen_mod:db_mod(LServer, ?MODULE),
     Mod:store_room(LServer, Host, Name, Opts, ChangesHints).
 
+store_changes(ServerHost, Host, Name, ChangesHints) ->
+    LServer = jid:nameprep(ServerHost),
+    Mod = gen_mod:db_mod(LServer, ?MODULE),
+    Mod:store_changes(LServer, Host, Name, ChangesHints).
+
 restore_room(ServerHost, Host, Name) ->
     LServer = jid:nameprep(ServerHost),
     Mod = gen_mod:db_mod(LServer, ?MODULE),
@@ -379,6 +397,25 @@ init([Host, Worker]) ->
 			 {stop, normal, ok, state()}.
 handle_call(stop, _From, State) ->
     {stop, normal, ok, State};
+handle_call({unhibernate, Room, Host}, _From,
+    #{server_host := ServerHost} = State) ->
+    RMod = gen_mod:ram_db_mod(ServerHost, ?MODULE),
+    {reply, load_room(RMod, Host, ServerHost, Room), State};
+handle_call({create, Room, Host, Opts}, _From,
+	    #{server_host := ServerHost} = State) ->
+    ?DEBUG("MUC: create new room '~ts'~n", [Room]),
+    NewOpts = case Opts of
+		  default -> mod_muc_opt:default_room_options(ServerHost);
+		  _ -> Opts
+	      end,
+    RMod = gen_mod:ram_db_mod(ServerHost, ?MODULE),
+    case start_room(RMod, Host, ServerHost, Room, NewOpts) of
+	{ok, _} ->
+	    ejabberd_hooks:run(create_room, ServerHost, [ServerHost, Room, Host]),
+	    {reply, ok, State};
+	Err ->
+	    {reply, Err, State}
+    end;
 handle_call({create, Room, Host, From, Nick, Opts}, _From,
 	    #{server_host := ServerHost} = State) ->
     ?DEBUG("MUC: create new room '~ts'~n", [Room]),
@@ -437,6 +474,15 @@ handle_info({route, Packet}, #{server_host := ServerHost} = State) ->
 handle_info({room_destroyed, {Room, Host}, Pid}, State) ->
     %% For backward compat
     handle_cast({room_destroyed, {Room, Host}, Pid}, State);
+handle_info({'DOWN', _Ref, process, Pid, _Reason},
+	    #{server_host := ServerHost} = State) ->
+    RMod = gen_mod:ram_db_mod(ServerHost, ?MODULE),
+    case RMod:find_online_room_by_pid(ServerHost, Pid) of
+	{ok, Room, Host} ->
+	    handle_cast({room_destroyed, {Room, Host}, Pid}, State);
+	_ ->
+	    {noreply, State}
+    end;
 handle_info(Info, State) ->
     ?ERROR_MSG("Unexpected info: ~p", [Info]),
     {noreply, State}.
@@ -531,7 +577,8 @@ unhibernate_room(ServerHost, Host, Room) ->
     RMod = gen_mod:ram_db_mod(ServerHost, ?MODULE),
     case RMod:find_online_room(ServerHost, Room, Host) of
 	error ->
-	    case load_room(RMod, Host, ServerHost, Room) of
+	    Proc = procname(ServerHost, {Room, Host}),
+	    case ?GEN_SERVER:call(Proc, {unhibernate, Room, Host}, 20000) of
 		{ok, _} = R -> R;
 		_ -> error
 	    end;
@@ -791,27 +838,15 @@ get_rooms(ServerHost, Host) ->
 load_permanent_rooms(Hosts, ServerHost, Opts) ->
     case mod_muc_opt:preload_rooms(Opts) of
 	true ->
-	    Access = get_access(Opts),
-	    HistorySize = mod_muc_opt:history_size(Opts),
-	    QueueType = mod_muc_opt:queue_type(Opts),
-	    RoomShaper = mod_muc_opt:room_shaper(Opts),
-	    RMod = gen_mod:ram_db_mod(Opts, ?MODULE),
 	    lists:foreach(
-	      fun(Host) ->
-		      ?DEBUG("Loading rooms at ~ts", [Host]),
-		      lists:foreach(
+		fun(Host) ->
+		    ?DEBUG("Loading rooms at ~ts", [Host]),
+		    lists:foreach(
 			fun(R) ->
-				{Room, _} = R#muc_room.name_host,
-				case RMod:find_online_room(ServerHost, Room, Host) of
-				    error ->
-					start_room(RMod, Host, ServerHost, Access,
-						   Room, HistorySize, RoomShaper,
-						   R#muc_room.opts, QueueType);
-				    {ok, _} ->
-					ok
-				end
+			    {Room, _} = R#muc_room.name_host,
+			    unhibernate_room(ServerHost, Host, Room)
 			end, get_rooms(ServerHost, Host))
-	      end, Hosts);
+		end, Hosts);
 	false ->
 	    ok
     end.
@@ -877,6 +912,7 @@ start_room(Mod, Host, ServerHost, Access, Room,
     case mod_muc_room:start(Host, ServerHost, Access, Room,
 			    HistorySize, RoomShaper, DefOpts, QueueType) of
 	{ok, Pid} ->
+	    erlang:monitor(process, Pid),
 	    Mod:register_online_room(ServerHost, Room, Host, Pid),
 	    {ok, Pid};
 	Err ->
@@ -889,6 +925,7 @@ start_room(Mod, Host, ServerHost, Access, Room, HistorySize,
 			    HistorySize, RoomShaper,
 			    Creator, Nick, DefOpts, QueueType) of
 	{ok, Pid} ->
+	    erlang:monitor(process, Pid),
 	    Mod:register_online_room(ServerHost, Room, Host, Pid),
 	    {ok, Pid};
 	Err ->
@@ -1329,19 +1366,19 @@ mod_doc() ->
               desc =>
                   ?T("To configure who is allowed to create new rooms at the "
                      "Multi-User Chat service, this option can be used. "
-                     "By default any account in the local ejabberd server is "
+                     "The default value is 'all', which means everyone is "
                      "allowed to create rooms.")}},
            {access_persistent,
             #{value => ?T("AccessName"),
               desc =>
                   ?T("To configure who is allowed to modify the 'persistent' room option. "
-                     "By default any account in the local ejabberd server is allowed to "
+                     "The default value is 'all', which means everyone is allowed to "
                      "modify that option.")}},
            {access_mam,
             #{value => ?T("AccessName"),
               desc =>
                   ?T("To configure who is allowed to modify the 'mam' room option. "
-                     "By default any account in the local ejabberd server is allowed to "
+                     "The default value is 'all', which means everyone is allowed to "
                      "modify that option.")}},
            {access_register,
             #{value => ?T("AccessName"),
@@ -1357,11 +1394,10 @@ mod_doc() ->
                      "store room information. The default is the storage defined "
                      "by the global option 'default_db', or 'mnesia' if omitted.")}},
            {ram_db_type,
-            #{value => "mnesia",
+            #{value => "mnesia | sql",
               desc =>
                   ?T("Define the type of volatile (in-memory) storage where the module "
-                     "will store room information. The only available value for this "
-                     "module is 'mnesia'.")}},
+                     "will store room information ('muc_online_room' and 'muc_online_users').")}},
            {hibernation_timeout,
             #{value => "infinity | Seconds",
               desc =>
@@ -1413,12 +1449,14 @@ mod_doc() ->
                      "The default value is 'infinity'.")}},
            {max_password,
             #{value => ?T("Number"),
+              note => "added in 21.01",
               desc =>
                   ?T("This option defines the maximum number of characters "
                      "that Password can have when configuring the room. "
                      "The default value is 'infinity'.")}},
            {max_captcha_whitelist,
             #{value => ?T("Number"),
+              note => "added in 21.01",
               desc =>
                   ?T("This option defines the maximum number of characters "
                      "that Captcha Whitelist can have when configuring the room. "
@@ -1456,7 +1494,8 @@ mod_doc() ->
                   ?T("This option defines after how many users in the room, "
                      "it is considered overcrowded. When a MUC room is considered "
                      "overcrowed, presence broadcasts are limited to reduce load, "
-                     "traffic and excessive presence \"storm\" received by participants.")}},
+                     "traffic and excessive presence \"storm\" received by participants. "
+                     "The default value is '1000'.")}},
            {min_message_interval,
             #{value => ?T("Number"),
               desc =>
@@ -1487,7 +1526,7 @@ mod_doc() ->
            {queue_type,
             #{value => "ram | file",
               desc =>
-                  ?T("Same as top-level 'queue_type' option, but applied to this module only.")}},
+                  ?T("Same as top-level _`queue_type`_ option, but applied to this module only.")}},
            {regexp_room_id,
             #{value => "string()",
               desc =>
@@ -1604,7 +1643,7 @@ mod_doc() ->
              {logging,
               #{value => "true | false",
                 desc =>
-                    ?T("The public messages are logged using 'mod_muc_log'. "
+                    ?T("The public messages are logged using _`mod_muc_log`_. "
                        "The default value is 'false'.")}},
              {members_by_default,
               #{value => "true | false",
