@@ -29,14 +29,16 @@
 -behaviour(mod_muc_room).
 
 %% API
--export([init/2, store_room/5, restore_room/3, forget_room/3,
+-export([init/2, store_room/5, store_changes/4,
+         restore_room/3, forget_room/3,
 	 can_use_nick/4, get_rooms/2, get_nick/3, set_nick/4,
 	 import/3, export/1]).
 -export([register_online_room/4, unregister_online_room/4, find_online_room/3,
 	 get_online_rooms/3, count_online_rooms/2, rsm_supported/0,
 	 register_online_user/4, unregister_online_user/4,
 	 count_online_rooms_by_user/3, get_online_rooms_by_user/3,
-	 get_subscribed_rooms/3, get_rooms_without_subscribers/2]).
+	 get_subscribed_rooms/3, get_rooms_without_subscribers/2,
+	 find_online_room_by_pid/2]).
 -export([set_affiliation/6, set_affiliations/4, get_affiliation/5,
 	 get_affiliations/3, search_affiliation/4]).
 
@@ -82,6 +84,12 @@ store_room(LServer, Host, Name, Opts, ChangesHints) ->
 	end,
     ejabberd_sql:sql_transaction(LServer, F).
 
+store_changes(LServer, Host, Name, Changes) ->
+    F = fun () ->
+                [change_room(Host, Name, Change) || Change <- Changes]
+	end,
+    ejabberd_sql:sql_transaction(LServer, F).
+
 change_room(Host, Room, {add_subscription, JID, Nick, Nodes}) ->
     SJID = jid:encode(JID),
     SNodes = misc:term_to_expr(Nodes),
@@ -184,13 +192,20 @@ get_rooms(LServer, Host) ->
 		{selected, Subs} ->
 		    SubsD = lists:foldl(
 			fun({Room, Jid, Nick, Nodes}, Dict) ->
-			    dict:append(Room, {jid:decode(Jid),
-					       Nick, ejabberd_sql:decode_term(Nodes)}, Dict)
-			end, dict:new(), Subs),
+                                Sub = {jid:decode(Jid),
+                                       Nick, ejabberd_sql:decode_term(Nodes)},
+                                maps:update_with(
+                                  Room,
+                                  fun(SubAcc) ->
+                                          [Sub | SubAcc]
+                                  end,
+                                  [Sub],
+                                  Dict)
+			end, maps:new(), Subs),
 	    lists:map(
 	      fun({Room, Opts}) ->
 			    OptsD = ejabberd_sql:decode_term(Opts),
-			    OptsD2 = case {dict:find(Room, SubsD), lists:keymember(subscribers, 1, OptsD)} of
+			    OptsD2 = case {maps:find(Room, SubsD), lists:keymember(subscribers, 1, OptsD)} of
 					 {_, true} ->
 					     store_room(LServer, Host, Room, mod_muc:opts_to_binary(OptsD), undefined),
 					     OptsD;
@@ -306,6 +321,21 @@ find_online_room(ServerHost, Room, Host) ->
 	    error
     end.
 
+find_online_room_by_pid(ServerHost, Pid) ->
+    PidS = misc:encode_pid(Pid),
+    NodeS = erlang:atom_to_binary(node(Pid), latin1),
+    case ejabberd_sql:sql_query(
+	ServerHost,
+	?SQL("select @(name)s, @(host)s from muc_online_room where "
+	     "node=%(NodeS)s and pid=%(PidS)s")) of
+	{selected, [{Room, Host}]} ->
+	    {ok, Room, Host};
+	{selected, []} ->
+	    error;
+	_Err ->
+	    error
+    end.
+
 count_online_rooms(ServerHost, Host) ->
     case ejabberd_sql:sql_query(
 	   ServerHost,
