@@ -409,9 +409,10 @@ get_member_jid(#state{user_jid_attr = UserJIDAttr, user_uid = UIDAttr} = State,
         [] ->
             {error, error};
         [#eldap_entry{attributes = [{UserJIDAttr, [MemberJID | _]}]} | _] ->
-            case jid:decode(MemberJID) of
-                error -> {error, Host};
+            try jid:decode(MemberJID) of
                 #jid{luser = U, lserver = S} -> {U, S}
+            catch
+                error:{bad_jid, _} -> {error, Host}
             end
     end.
 
@@ -795,7 +796,7 @@ mod_doc() ->
 		     "disable the check. Default value is 'true'.")}}] ++
           [{Opt,
             #{desc =>
-                  {?T("Same as top-level '~s' option, but "
+                  {?T("Same as top-level _`~s`_ option, but "
                       "applied to this module only."), [Opt]}}}
            || Opt <- [ldap_backups, ldap_base, ldap_uids, ldap_deref_aliases,
 		      ldap_encrypt, ldap_password, ldap_port, ldap_rootdn,
