@@ -159,7 +159,8 @@ mod_doc() ->
 	  ?T("This module allows XMPP clients to discover STUN/TURN services "
 	     "and to obtain temporary credentials for using them as per "
 	     "https://xmpp.org/extensions/xep-0215.html"
-	     "[XEP-0215: External Service Discovery]."),
+	     "[XEP-0215: External Service Discovery]. "
+	     "This module is included in ejabberd since version 20.04."),
       opts =>
 	  [{access,
 	    #{value => ?T("AccessName"),
@@ -175,7 +176,7 @@ mod_doc() ->
 		     "clients. If ejabberd's built-in TURN service is used, "
 		     "TURN relays allocated using temporary credentials will "
 		     "be terminated shortly after the credentials expired. The "
-		     "default value is '12' hours. Note that restarting the "
+		     "default value is '12 hours'. Note that restarting the "
 		     "ejabberd node invalidates any temporary credentials "
 		     "offered before the restart unless a 'secret' is "
 		     "specified (see below).")}},
